[FFmpeg-devel] [PATCH 08/15] avcodec/tak: Use void* instead of AVCodecContext* for logcontext

Andreas Rheinhardt andreas.rheinhardt at outlook.com
Wed Aug 2 13:58:30 EEST 2023


Avoids implicit inclusions of avcodec.h in lavf/takdec.c
and lavc/tak.c.

Signed-off-by: Andreas Rheinhardt <andreas.rheinhardt at outlook.com>
---
 libavcodec/tak.c | 4 ++--
 libavcodec/tak.h | 5 ++---
 2 files changed, 4 insertions(+), 5 deletions(-)

diff --git a/libavcodec/tak.c b/libavcodec/tak.c
index 99678e9887..91feac5451 100644
--- a/libavcodec/tak.c
+++ b/libavcodec/tak.c
@@ -144,11 +144,11 @@ int avpriv_tak_parse_streaminfo(TAKStreamInfo *s, const uint8_t *buf, int size)
     return tak_parse_streaminfo(s, &gb);
 }
 
-int ff_tak_decode_frame_header(AVCodecContext *avctx, GetBitContext *gb,
+int ff_tak_decode_frame_header(void *logctx, GetBitContext *gb,
                                TAKStreamInfo *ti, int log_level_offset)
 {
     if (get_bits(gb, TAK_FRAME_HEADER_SYNC_ID_BITS) != TAK_FRAME_HEADER_SYNC_ID) {
-        av_log(avctx, AV_LOG_ERROR + log_level_offset, "missing sync id\n");
+        av_log(logctx, AV_LOG_ERROR + log_level_offset, "missing sync id\n");
         return AVERROR_INVALIDDATA;
     }
 
diff --git a/libavcodec/tak.h b/libavcodec/tak.h
index 5e43598de8..1d1ee645e8 100644
--- a/libavcodec/tak.h
+++ b/libavcodec/tak.h
@@ -29,7 +29,6 @@
 
 #include <stdint.h>
 
-#include "avcodec.h"
 #include "get_bits.h"
 
 #define TAK_FORMAT_DATA_TYPE_BITS               3
@@ -151,13 +150,13 @@ int avpriv_tak_parse_streaminfo(TAKStreamInfo *s, const uint8_t *buf, int size);
 
 /**
  * Validate and decode a frame header.
  * @param      avctx             AVCodecContext to use as av_log() context
  * @param[in]  gb                GetBitContext from which to read frame header
  * @param[out] s                 frame information
  * @param      log_level_offset  log level offset, can be used to silence
  *                               error messages.
  * @return non-zero on error, 0 if OK
  */
-int ff_tak_decode_frame_header(AVCodecContext *avctx, GetBitContext *gb,
+int ff_tak_decode_frame_header(void *logctx, GetBitContext *gb,
                                TAKStreamInfo *s, int log_level_offset);
 #endif /* AVCODEC_TAK_H */
@@ -151,13 +150,13 @@ int avpriv_tak_parse_streaminfo(TAKStreamInfo *s, const uint8_t *buf, int size);
 /**
  * Validate and decode a frame header.
- * @param      avctx             AVCodecContext to use as av_log() context
+ * @param      logctx            for use as av_log() context
  * @param[in]  gb                GetBitContext from which to read frame header
  * @param[out] s                 frame information
-- 
2.34.1



More information about the ffmpeg-devel mailing list